Class: ReportingSettlementResearchApi::SettlementerrorsSettlementfileerrorsSearch0ErrorException

Inherits:
APIException
  • Object
show all
Defined in:
lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb

Overview

Settlementerrors Settlementfileerrors Search 0 Error class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ SettlementerrorsSettlementfileerrorsSearch0ErrorException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



27
28
29
30
31
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 27

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#error_codeString

Code of error

Returns:

  • (String)


14
15
16
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 14

def error_code
  @error_code
end

#error_messageString

Error Message

Returns:

  • (String)


18
19
20
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 18

def error_message
  @error_message
end

#targetString

Error Target

Returns:

  • (String)


22
23
24
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 22

def target
  @target
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



52
53
54
55
56
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 52

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code.inspect}, error_message:"\
  " #{@error_message.inspect}, target: #{@target.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



45
46
47
48
49
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 45

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code}, error_message: #{@error_message}, target:"\
  " #{@target}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



36
37
38
39
40
41
42
# File 'lib/reporting_settlement_research_api/exceptions/settlementerrors_settlementfileerrors_search0_error_exception.rb', line 36

def unbox(hash)
  return nil unless hash

  @error_code = hash.key?('errorCode') ? hash['errorCode'] : SKIP
  @error_message = hash.key?('errorMessage') ? hash['errorMessage'] : SKIP
  @target = hash.key?('target') ? hash['target'] : SKIP
end