Class: ReportingSettlementResearchApi::TransactionTypeCode

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/reporting_settlement_research_api/models/transaction_type_code.rb

Overview

The codes for the type of transactions.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code: SKIP, short_description: SKIP, long_description: SKIP, additional_properties: nil) ⇒ TransactionTypeCode

Returns a new instance of TransactionTypeCode.



47
48
49
50
51
52
53
54
55
56
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 47

def initialize(code: SKIP, short_description: SKIP, long_description: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @code = code unless code == SKIP
  @short_description = short_description unless short_description == SKIP
  @long_description = long_description unless long_description == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#codeString

The code of the transaction type.

Returns:

  • (String)


14
15
16
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 14

def code
  @code
end

#long_descriptionString

The long description of the transaction type.

Returns:

  • (String)


22
23
24
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 22

def long_description
  @long_description
end

#short_descriptionString

The short description of the transaction type.

Returns:

  • (String)


18
19
20
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 18

def short_description
  @short_description
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : SKIP
  short_description =
    hash.key?('shortDescription') ? hash['shortDescription'] : SKIP
  long_description =
    hash.key?('longDescription') ? hash['longDescription'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  TransactionTypeCode.new(code: code,
                          short_description: short_description,
                          long_description: long_description,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['short_description'] = 'shortDescription'
  @_hash['long_description'] = 'longDescription'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 34

def self.optionals
  %w[
    code
    short_description
    long_description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
96
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, short_description: #{@short_description.inspect},"\
  " long_description: #{@long_description.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, short_description: #{@short_description}, long_description:"\
  " #{@long_description}, additional_properties: #{@additional_properties}>"
end