Class: ReportingSettlementResearchApi::TransactionTypeCode
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ReportingSettlementResearchApi::TransactionTypeCode
- Defined in:
- lib/reporting_settlement_research_api/models/transaction_type_code.rb
Overview
The codes for the type of transactions.
Instance Attribute Summary collapse
-
#code ⇒ String
The code of the transaction type.
-
#long_description ⇒ String
The long description of the transaction type.
-
#short_description ⇒ String
The short description of the transaction type.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code: SKIP, short_description: SKIP, long_description: SKIP, additional_properties: nil) ⇒ TransactionTypeCode
constructor
A new instance of TransactionTypeCode.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code: SKIP, short_description: SKIP, long_description: SKIP, additional_properties: nil) ⇒ TransactionTypeCode
Returns a new instance of TransactionTypeCode.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 47 def initialize(code: SKIP, short_description: SKIP, long_description: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @code = code unless code == SKIP @short_description = short_description unless short_description == SKIP @long_description = long_description unless long_description == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#code ⇒ String
The code of the transaction type.
14 15 16 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 14 def code @code end |
#long_description ⇒ String
The long description of the transaction type.
22 23 24 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 22 def long_description @long_description end |
#short_description ⇒ String
The short description of the transaction type.
18 19 20 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 18 def short_description @short_description end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 59 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP short_description = hash.key?('shortDescription') ? hash['shortDescription'] : SKIP long_description = hash.key?('longDescription') ? hash['longDescription'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransactionTypeCode.new(code: code, short_description: short_description, long_description: long_description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['short_description'] = 'shortDescription' @_hash['long_description'] = 'longDescription' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 34 def self.optionals %w[ code short_description long_description ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
91 92 93 94 95 96 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 91 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, short_description: #{@short_description.inspect},"\ " long_description: #{@long_description.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
84 85 86 87 88 |
# File 'lib/reporting_settlement_research_api/models/transaction_type_code.rb', line 84 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, short_description: #{@short_description}, long_description:"\ " #{@long_description}, additional_properties: #{@additional_properties}>" end |